@@ -2,7 +2,7 @@
  * @file    configfile.c
  * @brief   handle configuration file
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person
@@ -73,7 +73,7 @@ const gchar config_str[] =
 "[Preview]\n"
 "zoommode = pagewidth\n"
 "pagelayout = one_column\n"
-"autosync = true\n"
+"autosync = False\n"
 "animated_scroll = always\n"
 "cache_size = 150\n"
 "\n"
@@ -91,7 +91,7 @@ const gchar config_str[] =
 "\n"
 "[CompileOpts]\n"
 "shellescape = True\n"
-"synctex = True\n"
+"synctex = False\n"
 "\n"
 "[Misc]\n"
 "recent1 = __NULL__\n"
@@ -130,7 +130,7 @@ void config_init (const gchar* filename) {
         }
         if (!g_file_test (filename, G_FILE_TEST_EXISTS) &&
             utils_set_file_contents (filename, text, -1)) {
-            slog (L_WARNING, "Old welcome text succesfully backed up..\n");
+            slog (L_WARNING, "Old welcome text successfully backed up..\n");
         }
         else {
             slog (L_WARNING, "Could not backup old welcome text..\n");
@@ -145,7 +145,7 @@ void config_init (const gchar* filename) {
         slog (L_INFO, "found old configuration file, replacing it with new "
                 "one ...\n");
         config_set_default ();
-    } else if (0 != g_strcmp0 (PACKAGE_VERSION, config_version)) {
+    } else if (!STR_EQU (PACKAGE_VERSION, config_version)) {
         slog (L_INFO, "updating version tag in configuration file...\n");
         config_set_value ("config_version", PACKAGE_VERSION);
     } else {
@@ -174,7 +174,7 @@ const gchar* config_get_value (const gchar* term) {
     slist* index = slist_find (config_head, term, FALSE, TRUE);
 
     ret = index->second;
-    if (ret && 0 == g_strcmp0 (ret, "False"))
+    if (ret && STR_EQU (ret, "False"))
         return NULL;
     return ret;
 }
