@@ -43,6 +43,7 @@
 #endif
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
+#include <unistd.h>
 
 #include "configfile.h"
 #include "constants.h"
@@ -121,11 +122,17 @@ GuEditor* editor_new (GuMotion* mc) {
 
 void editor_destroy (GuEditor* ec) {
     gint i = 0;
-
-    for (i = 0; i < 2; ++i)
-        g_signal_handler_disconnect (ec->view, ec->sigid[i]);
-    for (i = 2; i < 5; ++i)
-        g_signal_handler_disconnect (ec->buffer, ec->sigid[i]);
+    
+    for (i = 0; i < 2; ++i) {
+        if (g_signal_handler_is_connected (ec->view, ec->sigid[i])) {
+            g_signal_handler_disconnect (ec->view, ec->sigid[i]);
+        }
+    }
+    for (i = 2; i < 5; ++i) {
+        if (g_signal_handler_is_connected (ec->buffer, ec->sigid[i])) {
+            g_signal_handler_disconnect (ec->buffer, ec->sigid[i]);
+        }
+    }
 
     editor_fileinfo_cleanup (ec);
     g_free(ec);
@@ -714,8 +721,7 @@ static inline gdouble gdkcolor_luminance(GdkColor c) {
  *  be white or black, which has more contrast.
  */
 void set_style_fg_bg (GObject* obj, GtkSourceStyleScheme* scheme, 
-                      gchar* styleName, gchar* defaultBG)
-{
+                      gchar* styleName, gchar* defaultBG) {
     GtkSourceStyle *style = NULL;
     
     gchar *bg = NULL;
