@@ -130,6 +130,8 @@ GummiGui* gui_init (GtkBuilder* builder) {
         GTK_MENU_ITEM (gtk_builder_get_object (builder, "menu_runbibtex"));
     g->menu_runmakeindex =
         GTK_MENU_ITEM (gtk_builder_get_object (builder, "menu_runmakeindex"));
+    g->bibcompile =
+        GTK_WIDGET (gtk_builder_get_object (builder, "bibcompile"));
 
     g->insens_widget_size = sizeof(insens_widgets_str) / sizeof(gchar*);
     g->insens_widgets = g_new0(GtkWidget*, g->insens_widget_size);
@@ -148,7 +150,7 @@ GummiGui* gui_init (GtkBuilder* builder) {
     g->infoscreengui = infoscreengui_init (builder);
     g->projectgui = projectgui_init (builder);
 
-    gchar* icon_file = g_build_filename (DATADIR, "icons", "icon.png", NULL);
+    gchar* icon_file = g_build_filename (GUMMI_DATA, "icons", "icon.png", NULL);
     gtk_window_set_icon_from_file (g->mainwindow, icon_file, NULL);
     g_free (icon_file);
     gtk_window_resize (g->mainwindow,
@@ -293,6 +295,7 @@ void on_menu_autosync_toggled (GtkCheckMenuItem *menu_autosync, void* user) {
 G_MODULE_EXPORT
 void on_tab_notebook_switch_page(GtkNotebook *notebook, GtkWidget *nbpage,
                                  int pagenr, void *data) {
+    slog (L_DEBUG, "Switched to environment at page %d\n", pagenr);
     /* Kill typesetter command */
     motion_kill_typesetter(gummi->motion);
 
@@ -306,7 +309,6 @@ void on_tab_notebook_switch_page(GtkNotebook *notebook, GtkWidget *nbpage,
     gui_buildlog_set_text ("");
     
     previewgui_reset (gui->previewgui);
-    slog (L_DEBUG, "Switched to environment at page %d\n", pagenr);
 }
 
 G_MODULE_EXPORT
@@ -322,8 +324,7 @@ void on_right_notebook_switch_page(GtkNotebook *notebook, GtkWidget *nbpage,
     }
 }
 
-void gui_set_filename_display (GuTabContext* tc, gboolean title, gboolean label)
-{
+void gui_set_filename_display (GuTabContext* tc, gboolean title, gboolean label) {
     gchar* filetext = tabmanager_get_tabname (tc);
     
     if (label) tabmanagergui_update_label (tc->page, filetext);
@@ -583,20 +584,22 @@ void on_bibcolumn_clicked (GtkWidget* widget, void* user) {
 G_MODULE_EXPORT
 void on_button_biblio_compile_clicked (GtkWidget* widget, void* user) {
     gummi->biblio->progressval = 0.0;
+    
+    gtk_widget_set_sensitive (widget, FALSE);
     g_timeout_add (10, on_bibprogressbar_update, NULL);
 
     if (biblio_compile_bibliography (gummi->biblio, g_active_editor,
                 gummi->latex)) {
         statusbar_set_message (_("Compiling bibliography file..."));
         gtk_progress_bar_set_text (gummi->biblio->progressbar,
-                _("bibliography compiled without errors"));
+                _("Bibliography compiled without errors"));
+        motion_force_compile (gummi->motion);
     } else {
-        statusbar_set_message (_("Error compiling bibliography file or none "
-                    "detected..."));
+        statusbar_set_message 
+        (_("Error compiling bibliography file or none detected..."));
         gtk_progress_bar_set_text (gummi->biblio->progressbar,
-                _("error compiling bibliography file"));
+                _("Error compiling bibliography file"));
     }
-    motion_force_compile (gummi->motion);
 }
 
 G_MODULE_EXPORT
@@ -722,15 +725,36 @@ gboolean on_bibprogressbar_update (void* user) {
     gtk_adjustment_set_value
         (gummi->biblio->progressmon, gummi->biblio->progressval);
     gummi->biblio->progressval += 1.0;
-    return ! (gummi->biblio->progressval > 60);
+    if (gummi->biblio->progressval > 60) {
+        gtk_widget_set_sensitive (gui->bibcompile, TRUE);
+        return FALSE;
+    }
+    return TRUE;
 }
 
 gint check_for_save (GuEditor* editor) {
+    GtkWidget* dialog;
     gint ret = 0;
-
-    if (editor && editor_buffer_changed (editor))
-        ret = utils_yes_no_dialog (
-                _("Do you want to save the changes you have made?"));
+    
+    if (editor && editor_buffer_changed (editor)){
+        dialog = gtk_message_dialog_new (gui->mainwindow,
+                     GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                     GTK_MESSAGE_QUESTION,
+                     GTK_BUTTONS_NONE,
+                     _("Do you want to save the changes to %s?"),
+                     editor->filename != NULL ? g_path_get_basename (editor->filename) : _("this document"));
+        gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+                                GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                GTK_STOCK_DISCARD, GTK_RESPONSE_NO,
+                                GTK_STOCK_SAVE, GTK_RESPONSE_YES,
+                                NULL);
+        gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
+        
+        gtk_window_set_title (GTK_WINDOW (dialog), _("Unsaved Changes"));
+        ret = gtk_dialog_run (GTK_DIALOG (dialog));
+        gtk_widget_destroy (dialog);
+    }
+    
     return ret;
 }
 
