@@ -58,9 +58,13 @@ GuMenuGui* menugui_init (GtkBuilder* builder) {
                         gtk_builder_get_object (builder, "menu_projclose"));
     
     #ifdef WIN32
-    /* please do not enable for nix, it has no place on a free OS ;)*/
+    // Please do NOT enable for nix, it has no place on a free OS ;)
     GtkWidget* donate = 
-		gtk_menu_item_new_with_label ("Support this Project");
+		gtk_image_menu_item_new_with_label ("Support this Project");
+    gtk_image_menu_item_set_image 
+        (GTK_IMAGE_MENU_ITEM(donate), 
+         GTK_WIDGET(gtk_image_new_from_stock(
+         GTK_STOCK_DIALOG_QUESTION, GTK_ICON_SIZE_MENU)));
     GtkWidget* helpmenu = 
 		GTK_WIDGET (gtk_builder_get_object (builder, "menu11"));
     gtk_menu_prepend (GTK_MENU (helpmenu), donate);
@@ -69,6 +73,32 @@ GuMenuGui* menugui_init (GtkBuilder* builder) {
                                NULL);
     #endif
     
+    /* TODO: There has to be a better way than this.. (bug 246)
+    GtkSettings *settings = gtk_settings_get_default();
+    gchar *iconsizes;
+    g_object_get(settings, "gtk-icon-sizes", &iconsizes, NULL);
+    if (iconsizes != NULL) {
+        printf("%s\n", iconsizes);
+    }*/ 
+
+    #ifdef WIN32
+        // The 2 non-stock menu items have their pixel size values set 
+        // to the default 16x16 in GLADE. The normal icon-size value is 
+        // normally set by the GTK theme in gtkrc. For themes using
+        // non-default icon sizes or Windows, this 16x16 value will be
+        // wrong. This code sets it to match the gtkrc file that we 
+        // supply with the Windows builds:
+        GtkWidget* export = gtk_image_menu_item_get_image (
+        GTK_IMAGE_MENU_ITEM (gtk_builder_get_object (builder, "menu_export")));
+        GtkWidget* update = gtk_image_menu_item_get_image (
+        GTK_IMAGE_MENU_ITEM (gtk_builder_get_object (builder, "menu_update")));
+        gtk_image_set_pixel_size (GTK_IMAGE(export), 13);
+        gtk_image_set_pixel_size (GTK_IMAGE(update), 13);
+    #endif
+ 
+
+    
+    
     return m;
 }
 
@@ -77,7 +107,7 @@ G_MODULE_EXPORT
 void on_menu_donate_activate (GtkWidget* widget, void* user) {
 	//TODO: enhance
 	GtkWidget* dialog;
-    dialog = gtk_message_dialog_new (NULL, 
+    dialog = gtk_message_dialog_new (gui->mainwindow, 
         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
         GTK_MESSAGE_INFO,
         GTK_BUTTONS_OK,
@@ -200,9 +230,7 @@ gboolean on_menu_quit_activate (void) {
     int i = 0;
     gint length = g_list_length (gummi->tabmanager->tabs);
 
-    /* Stop compile thread */
-    if (length > 0) motion_stop_compile_thread (gummi->motion);
-
+    motion_pause_compile_thread (gummi->motion);
     for(i = 0; i < length; i++){
         gtk_notebook_set_current_page(gui->tabmanagergui->notebook, i);
         tabmanager_set_active_tab (i);
@@ -214,6 +242,9 @@ gboolean on_menu_quit_activate (void) {
             return TRUE;
     }
 
+    /* Stop compile thread */
+    if (length > 0) motion_stop_compile_thread (gummi->motion);
+
     gtk_window_get_size (gui->mainwindow, &width, &height);
     gtk_window_get_position (gui->mainwindow, &wx, &wy);
 
@@ -664,7 +695,7 @@ void on_menu_update_activate (GtkWidget *widget, void *user) {
 G_MODULE_EXPORT
 void on_menu_about_activate (GtkWidget *widget, void *user) {
     GError* err = NULL;
-    gchar* icon_file = g_build_filename (DATADIR, "icons", "gummi.png", NULL);
+    gchar* icon_file = g_build_filename (GUMMI_DATA, "icons", "gummi.png", NULL);
     GdkPixbuf* icon = gdk_pixbuf_new_from_file_at_size (icon_file, 80, 80, &err);
     g_free (icon_file);
 
@@ -673,7 +704,9 @@ void on_menu_about_activate (GtkWidget *widget, void *user) {
         "Wei-Ning Huang\n"
         "<aitjcize@gmail.com>",
         "Dion Timmermann",
-        "<dion.timmermann@tu-harburg.de>\n", 
+        "<dion.timmermann@tu-harburg.de>", 
+        "Robert Schroll",
+        "<rschroll@gmail.com>\n",
         "Former contributors:",
         "Thomas van der Burgt",
         "Cameron Grout", NULL };
@@ -693,6 +726,7 @@ void on_menu_about_activate (GtkWidget *widget, void *user) {
         "French: Yvan Duron & Olivier Brousse\n"
         "German: Thomas Niederprüm\n"
         "Greek: Dimitris Leventeas\n"
+        "Hungarian: Balázs Meskó\n"
         "Italian: Salvatore Vassallo\n"
         "Polish: Hubert Kowalski\n"
         "Portugese: Alexandre Guimarães\n"
