@@ -65,7 +65,7 @@ static void set_tab_miscellaneous_settings (GuPrefsGui* prefs);
 GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
     GuPrefsGui* p = g_new0 (GuPrefsGui, 1);
     GtkBuilder* builder = gtk_builder_new ();
-    gchar* ui = g_build_filename (DATADIR, "ui", "prefs.glade", NULL);
+    gchar* ui = g_build_filename (GUMMI_DATA, "ui", "prefs.glade", NULL);
     gtk_builder_add_from_file (builder, ui, NULL);
     gtk_builder_set_translation_domain (builder, PACKAGE);
     g_free (ui);
@@ -150,27 +150,30 @@ GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
 #ifdef USE_GTKSPELL
     /* list available languages */
 
-    Tuple2 pret = utils_popen_r ("enchant-lsmod -list-dicts", NULL);
-
-    if (pret.second != NULL) {
-        gchar** output = g_strsplit((gchar*)pret.second, "\n", BUFSIZ);
-        gchar** elems = NULL;
-        int i;
-
-        for(i = 0; output[i] != NULL; i++) {
-            GtkTreeIter iter;
-            elems = g_strsplit (output[i], " ", BUFSIZ);
-            if (elems[0] != NULL) {
-                gtk_list_store_append (p->list_languages, &iter);
-                gtk_list_store_set (p->list_languages, &iter, 0, elems[0], -1);
+    
+    if (g_file_test (
+        g_find_program_in_path("enchant-lsmod"), G_FILE_TEST_EXISTS)) {
+            
+        Tuple2 pret = utils_popen_r ("enchant-lsmod -list-dicts", NULL);
+        if (pret.second != NULL) {
+            gchar** output = g_strsplit((gchar*)pret.second, "\n", BUFSIZ);
+            gchar** elems = NULL;
+            int i;
+    
+            for(i = 0; output[i] != NULL; i++) {
+                GtkTreeIter iter;
+                elems = g_strsplit (output[i], " ", BUFSIZ);
+                if (elems[0] != NULL) {
+                    gtk_list_store_append (p->list_languages, &iter);
+                    gtk_list_store_set (p->list_languages, &iter, 0, elems[0], -1);
+                }
             }
+        g_strfreev(output);
+        g_strfreev(elems);
         }
-    g_strfreev(output);
-    g_strfreev(elems);
+        gtk_combo_box_set_active (p->combo_languages, 0);
+        g_free ((gchar*)pret.second);
     }
-
-    gtk_combo_box_set_active (p->combo_languages, 0);
-    g_free ((gchar*)pret.second);
 #else
     /* desensitise gtkspell related GUI elements if not used */
     GtkWidget* box = GTK_WIDGET (
@@ -758,8 +761,7 @@ void on_combo_animated_scroll_changed (GtkWidget* widget, void* user) {
 }
 
 G_MODULE_EXPORT
-void on_styleschemes_treeview_cursor_changed (GtkTreeView* treeview, void* user)
-{
+void on_styleschemes_treeview_cursor_changed (GtkTreeView* treeview, void* user) {
     gchar* id = NULL;
     gchar* name = NULL;
     GList* tab = gummi->tabmanager->tabs;
