@@ -50,14 +50,11 @@
 
 #include "syncTeX/synctex_parser.h"
 
-
 /* set up uri using appropriate formatting for OS
    http://en.wikipedia.org/wiki/File_URI_scheme#Linux */
 #ifdef WIN32
-    const gchar *urifrmt = "file:///";
     gint usize = 8;
 #else
-    const gchar *urifrmt = "file://";
     gint usize = 7;
 #endif
 
@@ -329,8 +326,7 @@ inline static gboolean is_hscrollbar_visible(GuPreviewGui* pc) {
 }
 
 G_MODULE_EXPORT
-void previewgui_page_layout_radio_changed(GtkMenuItem *radioitem, gpointer data)
-{
+void previewgui_page_layout_radio_changed(GtkMenuItem *radioitem, gpointer data) {
     //L_F_DEBUG;
 
     if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM(radioitem))) {
@@ -571,6 +567,7 @@ static void update_page_input(GuPreviewGui* pc) {
 }
 
 static void update_page_positions(GuPreviewGui* pc) {
+    //L_F_DEBUG;
 
     LayeredRectangle fov = get_fov(pc);
     int i;
@@ -794,8 +791,7 @@ static void update_page_sizes(GuPreviewGui* pc) {
     update_fit_scale(pc);
 }
 
-void previewgui_set_page_layout(GuPreviewGui* pc, PopplerPageLayout pageLayout)
-{
+void previewgui_set_page_layout(GuPreviewGui* pc, PopplerPageLayout pageLayout) {
     //L_F_DEBUG;
 
     if (pageLayout == POPPLER_PAGE_LAYOUT_UNSET) {
@@ -923,11 +919,11 @@ static void load_document(GuPreviewGui* pc, gboolean update) {
     update_prev_next_page(pc);
 }
 
-void previewgui_set_pdffile (GuPreviewGui* pc, const gchar *pdffile) {
+void previewgui_set_pdffile (GuPreviewGui* pc, const gchar *uri) {
     //L_F_DEBUG;
     previewgui_cleanup_fds (pc);
 
-    pc->uri = g_strconcat (urifrmt, pdffile, NULL);
+    pc->uri = g_strdup(uri);
 
     pc->doc = poppler_document_new_from_file (pc->uri, NULL, NULL);
     g_return_if_fail (pc->doc != NULL);
@@ -968,6 +964,7 @@ void previewgui_set_pdffile (GuPreviewGui* pc, const gchar *pdffile) {
 
 void previewgui_refresh (GuPreviewGui* pc, GtkTextIter *sync_to,
         gchar* tex_file) {
+    //L_F_DEBUG;
     /* We lock the mutex to prevent previewing imcomplete PDF file, i.e
      * compiling. Also prevent PDF from changing (compiling) when previewing */
     if (!g_mutex_trylock (gummi->motion->compile_mutex)) return;
@@ -975,6 +972,12 @@ void previewgui_refresh (GuPreviewGui* pc, GtkTextIter *sync_to,
     /* This line is very important, if no pdf exist, preview will fail */
     if (!pc->uri || !utils_path_exists (pc->uri + usize)) goto unlock;
 
+    // If no document had been loaded successfully before, force call of set_pdffile
+    if (pc->doc == NULL) {
+        previewgui_set_pdffile (pc, pc->uri);
+        goto unlock;
+    }
+
     previewgui_cleanup_fds (pc);
 
     pc->doc = poppler_document_new_from_file (pc->uri, NULL, NULL);
@@ -1576,8 +1579,7 @@ void on_combo_sizes_changed (GtkWidget* widget, void* user) {
 
 }
 
-static void paint_page(cairo_t *cr, GuPreviewGui* pc, gint page, gint x, gint y)
-{
+static void paint_page (cairo_t *cr, GuPreviewGui* pc, gint page, gint x, gint y) {
     if (page < 0 || page >= pc->n_pages) {
         return;
     }
@@ -1639,6 +1641,8 @@ static void paint_page(cairo_t *cr, GuPreviewGui* pc, gint page, gint x, gint y)
 }
 
 static inline LayeredRectangle get_fov(GuPreviewGui* pc) {
+    //L_F_DEBUG;
+    
     LayeredRectangle fov;
     fov.x = gtk_adjustment_get_value(pc->hadj);
     fov.y = gtk_adjustment_get_value(pc->vadj);
@@ -1815,6 +1819,8 @@ gboolean on_expose (GtkWidget* w, GdkEventExpose* e, void* user) {
 //    slog(L_INFO, "paint document with scale %f, region (%i, %i), w=%i,
 //    h=%i\n", e->area.x, e->area.y, e->area.width, e->area.height);
 
+    //slog(L_INFO, "scale: %f", pc->scale);
+
     if (!pc->uri || !utils_path_exists (pc->uri + usize)) {
 
         return FALSE;
