@@ -2,7 +2,7 @@
  * @file    iofunctions.h
  * @brief   
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person
@@ -48,6 +48,8 @@ GuIOFunc* iofunctions_init (void);
 void iofunctions_load_default_text (gboolean loopedonce);
 void iofunctions_load_file (GuIOFunc* io, const gchar* filename);
 void iofunctions_save_file (GuIOFunc* io, gchar* filename, gchar *text);
+gchar* iofunctions_get_swapfile (const gchar* filename);
+gboolean iofunctions_has_swapfile (const gchar* filename);
 void iofunctions_start_autosave (void);
 void iofunctions_stop_autosave (void);
 void iofunctions_reset_autosave (const gchar* name);
