@@ -2,7 +2,7 @@
  * @file    template.h
  * @brief   
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person
@@ -45,9 +45,9 @@ typedef struct _Template {
     GtkCellRendererText* template_render;
     GtkTreeViewColumn* template_col;
     GtkLabel* template_label;
-    GtkButton* template_add;
-    GtkButton* template_remove;
-    GtkButton* template_open;
+    GtkWidget* template_add;
+    GtkWidget* template_remove;
+    GtkWidget* template_open;
 } GuTemplate;
 
 
