@@ -2,7 +2,7 @@
  * @file    utils.h
  * @brief   
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person
@@ -41,6 +41,7 @@
 #endif
 
 #define TO_BOOL(X) ((X)? TRUE: FALSE)
+#define STR_EQU(X, Y) (g_strcmp0((X), (Y)) == 0)
 
 #define L_IS_TYPE(level, type) ((level & type) == type)
 #define L_IS_GUI(level) (level & 0xf0)
@@ -137,7 +138,7 @@ gboolean utils_copy_file (const gchar* source, const gchar* dest, GError** err);
  *
  * Platform independent interface for calling popen ().
  */
-Tuple2 utils_popen_r (const gchar* cmd);
+Tuple2 utils_popen_r (const gchar* cmd, const gchar* chdir);
 
 /**
  * utils_path_to_relative:
@@ -158,13 +159,14 @@ gchar* utils_path_to_relative (const gchar* root, const gchar* target);
  */
 gboolean utils_subinstr (const gchar* substr, const gchar* target,
         gboolean case_sens);
-gboolean utils_strequal (const gchar* str1, const gchar* str2);
 
 gchar* utils_get_tmp_tmp_dir (void); /* TODO: remove when we can */
 
 
 gboolean utils_glist_is_member (GList *list, gchar* item);
 
+gchar* g_substr(gchar* src, gint start, gint end);
+
 /**
  * slist_find:
  * @head: the list head
